#!/usr/bin/env python3
# coding: utf-8

"""
Description: Preparations for building project
Create: 2021-02-18
Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
"""

import sys
import os
from tools import common
from tools import utils


class PostBuild(object):
    """
    编译后处理
    """
    def __init__(self):
        self.elf_file = os.path.join(common.PROJ_BUILD_TMP_DIR,
                                     "{}.elf".format(common.PROJ_EXECUTE_NAME))
        self.s19_file = os.path.join(common.PROJ_BUILD_TMP_DIR,
                                "{}.s19".format(common.PROJ_EXECUTE_NAME))


    def srec_cal_crc(self, code_file, intact_file, output_file, srec_version):
        """boot的s19文件处理"""
        #计算code的crc
        build_dir = common.PROJ_BUILD_TMP_DIR
        start_addr = common.APP_START_ADDR
        end_addr = common.APP_END_ADDR
        len_fg_addr = end_addr - 2 * common.PF_PAGE_LEN
        len_addr = len_fg_addr + 0x8
        len_fg_cs_addr = len_addr + 0x4
        crc_fg_addr = len_fg_cs_addr + 0x4
        crc_addr = crc_fg_addr + 0x8
        crc_fg_cs_addr = crc_addr + 0x4
        code_file = os.path.join(build_dir, "code_file.s19")
        len_file = os.path.join(build_dir, "len_file.s19")
        tmp_file = os.path.join(build_dir, "tmp_file.s19")
        tmp_flag_file = os.path.join(build_dir, "tmp_flag_file.s19")
        tmp_cs_file = os.path.join(build_dir, "tmp_cs_file.s19")
        crc_file = os.path.join(build_dir, "crc_file.s19")
        no_code_file = os.path.join(build_dir, "no_code_file.s19")
        head_info = common.SREC_HEADER_INFO
        cmd_list = []
        if "1.58.D001" in srec_version:
            crc_cmd = "-l-e-crc32"
            checksum_cmd = "-l-e-checksum-positive"
        else:
            crc_cmd = "-crc32-l-e"
            checksum_cmd = "-checksum-positive-l-e"
        cmd_list.append("srec_cat {} {} {} -crop {} {} \
            -execution-start-address={} -o {}".format(code_file, crc_cmd,
            crc_addr, crc_fg_addr, crc_fg_cs_addr, start_addr, tmp_file))
        #拆分
        cmd_list.append("srec_cat {} -crop {} {} -execution-start-address={} -o \
            {}".format(intact_file, crc_fg_addr, crc_addr, start_addr, tmp_flag_file))
        #合并标志位和crc
        cmd_list.append("srec_cat {} {} -o {}".format(
            tmp_flag_file, tmp_file, tmp_cs_file))
        #计算crc标志的checksum
        cmd_list.append("srec_cat {} {} {} 4 1 \
            -o {}".format(tmp_cs_file, checksum_cmd, crc_addr + 0x4, crc_file))
        #拆分出除代码以外的数据
        cmd_list.append("srec_cat {} -exclude {} {} \
            -execution-start-address={} -o {}".format(intact_file, start_addr,
            end_addr - common.PF_PAGE_LEN, start_addr, no_code_file))
        #合并多个文件
        cmd_list.append("srec_cat {} {} {} {} -o {}".format(
            code_file, len_file, crc_file, no_code_file, tmp_file))
        #32字节对齐并删除无效信息
        cmd_list.append("srec_cat {} -fill 0x00 -within {} -range-pad 32 \
            -header=""{}"" -disable=data-count -disable=exec-start-addr \
            -disable=footer -o {}".format(tmp_file, tmp_file, head_info, output_file))
        for cmd in cmd_list:
            if utils.execute_process(cmd) != 0:
                utils.show_err("Failed to cmd: {}".format(cmd))
                return False
        return True

    def srec_process(self, input_file, output_file, srec_version):
        """boot的s19文件处理"""
        build_dir = common.PROJ_BUILD_TMP_DIR
        start_addr = common.APP_START_ADDR
        end_addr = common.APP_END_ADDR
        len_fg_addr = end_addr - 2 * common.PF_PAGE_LEN
        len_addr = len_fg_addr + 0x8
        len_fg_cs_addr = len_addr + 0x4
        intact_file = os.path.join(build_dir, "intact_file.s19")
        code_file = os.path.join(build_dir, "code_file.s19")
        len_file = os.path.join(build_dir, "len_file.s19")
        tmp_flag_file = os.path.join(build_dir, "tmp_flag_file.s19")
        tmp_file = os.path.join(build_dir, "tmp_file.s19")
        tmp_cs_file = os.path.join(build_dir, "tmp_cs_file.s19")
        cmd_list = []
        if "1.58.D001" in srec_version:
            len_cmd = "-l-e-length"
            checksum_cmd = "-l-e-checksum-pos"
        else:
            len_cmd = "-length-l-e"
            checksum_cmd = "-checksum-pos-l-e"
        cmd_list.append("srec_cat {} -fill 0x00 -within {} -range-pad 32 \
            -o {}".format(input_file, input_file, intact_file))
        #拆分
        cmd_list.append("srec_cat {} -crop {} {} -o {}".format(
            intact_file, start_addr, len_fg_addr, input_file))
        #自适应填充code
        cmd_list.append("srec_cat {} -fill 0x00 -over {} \
            -o {}".format(input_file, input_file, code_file))
        #获取代码长度
        cmd_list.append("srec_cat {} -exclude {} {} {} {} 4 -crop {} \
            {} -execution-start-address={} -o {}".format(code_file, start_addr,
            start_addr + 0x20, len_cmd, start_addr, start_addr, start_addr + 0x20,
            start_addr, tmp_file))
        #拆分
        cmd_list.append("srec_cat {} -crop {} {} -execution-start-address={} -o \
            {}".format(intact_file, len_fg_addr, len_addr, start_addr, tmp_flag_file))
        #合并标志位和长度
        cmd_list.append("srec_cat {} {} -offset {} -o {}".format(
            tmp_flag_file, tmp_file, len_addr - start_addr, tmp_cs_file))
        #计算长度标志的checksum
        cmd_list.append("srec_cat {} {} {} 4 1 -o {}".format(
            tmp_cs_file, checksum_cmd, len_fg_cs_addr, len_file))
        for cmd in cmd_list:
            if utils.execute_process(cmd) != 0:
                utils.show_err("Failed to cmd: {}".format(cmd))
                return False
        if self.srec_cal_crc(code_file, intact_file, output_file, srec_version) != True:
            return False
        return True


    def generate_s19_file(self):
        """生成s19文件"""
        tmp_s19_file = os.path.join(common.PROJ_BUILD_TMP_DIR,
                                    "{}.s19".format(self.elf_file))
        if not os.path.exists(self.elf_file):
            utils.show_err("elf file {} is not exists".format(self.elf_file))
            return False

        objcopy_cmd = "tricore-objcopy -O srec {} {}".format(
            self.elf_file, tmp_s19_file)
        if utils.execute_process(objcopy_cmd) != 0 or \
            not os.path.exists(tmp_s19_file):
            utils.show_err("Do objcopy_cmd failed!")
            return False

        ret, srec_version = utils.excute_cmd("srec_cat -version")
        if self.srec_process(tmp_s19_file, self.s19_file, srec_version) != True:
            return False
        utils.remove(tmp_s19_file)
        return True

    def output_execute_file(self):
        utils.copy(self.elf_file, common.PROJ_OUTPUT_DIR)
        utils.copy(self.s19_file, common.PROJ_OUTPUT_DIR)
        return True

    def get_version_info(self):
        """获取版本信息"""
        version_max_len = 32
        version_info_file = os.path.join(common.PROJ_VER_INFO_DIR,
                                         "version_info.h")
        version_file = os.path.join(common.PROJ_OUTPUT_DIR, "version.txt")
        get_version_cmd = """cat %s | grep '#define MDC_MCU_VERSION' | \
        awk '{print $3}' |sed 's/\\"//g' > %s""" % (version_info_file,
                                                    version_file)
        if utils.execute_process(get_version_cmd) != 0:
            utils.show_err("Failed to get version info!")
            return False

        with open(version_file, 'r', encoding='utf-8') as file:
            version_str = file.read()
        version_len = len(version_str)
        if version_len > version_max_len:
            utils.show_err(f"Version len must be smaller than {version_max_len}, current len: {version_len}")
            return False

        sed_cmd = "sed -i 's/^/version:/' {}".format(version_file)
        if utils.execute_process(sed_cmd) != 0:
            utils.show_err("Failed to sed version.txt!")
            return False

        return True

    def run(self):
        """PostBuild 入口"""
        if not self.generate_s19_file():
            utils.show_err("Generate s19 file failed!")
            return False

        if not self.output_execute_file():
            utils.show_err("Output execute file failed!")
            return False

        if not self.get_version_info():
            utils.show_err("Get version info failed!")
            return False

        return True
