#!/usr/bin/env python3
# coding: utf-8

"""
Description: Preparations for building project
Create: 2021-02-18
Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
"""

import sys
import os
from tools import common
from tools import utils


class PreBuild(object):
    """
    编译前处理
    """
    @staticmethod
    def create_temp_dir():
        """创建临时目录"""
        utils.mkdir(common.PROJ_BUILD_TMP_DIR)
        return True

    @staticmethod
    def gen_ld_file():
        """ 生成ld文件 """
        ld_origin = os.path.join(common.PROJ_LINK_FILE_DIR,
                             "ee_tc_gcc_flash_tmp.ld")
        ld_temp = os.path.join(common.PROJ_LINK_FILE_DIR,
                             "ee_tc_gcc_flash_tmp.c")
        ld_target = os.path.join(common.PROJ_LINK_FILE_DIR, 
                             "ee_tc_gcc_flash_project.ld")
        if not os.path.exists(ld_origin):
            utils.show_err("ee_tc_gcc_flash_tmp.ld does not exits!")
            os._exit(1)
        utils.execute_process("cp {} {}".format(
            ld_origin, ld_temp))

        # 生成最终的结果文件
        gen_ld_cmd = "gcc -E -P {} -o {}".format(ld_temp, ld_target)
        if utils.execute_process(gen_ld_cmd) != 0:
            os._exit(1)

        utils.remove(ld_temp)
        return True

    def run(self):
        """Prebuild 入口"""

        if not self.create_temp_dir():
            utils.show_err("Create temp dir failed")
            return False
        if not self.gen_ld_file():
            utils.show_err("gen ld file failed")
            return False

        return True
