/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2023-2023. All rights reserved..
 * Description: 定义基础算法库
 * Author: x00450160
 * Create: 2023-05-15
 * Notes:
 */
#ifndef NCS_SECOCKEYPARSE_H
#define NCS_SECOCKEYPARSE_H
#include "ncs_datatype.h"

#define KEY_BYTES_LEN           16U
#define NCS_VIN_CODE_LEN        17U
#define NCS_REMAIN_DIV          2U

typedef struct {
    uint32 len;
    uint8 usedIv[KEY_BYTES_LEN];
    uint8 usedKey[KEY_BYTES_LEN];
    uint8 usedSc[KEY_BYTES_LEN];
    const uint8 *inArray;
    const uint8 *vinArray;
    uint8 *outArray;
} AlgorithmLocalDataType;

typedef struct {
    uint8* dataPtr;
    uint32 len;
} AlgorithmOutDataType;

typedef struct {
    const uint8* dataPtr;
    uint32 len;
} AlgorithmInDataType;

typedef void (*OperateFuncType)(AlgorithmLocalDataType *localData);
typedef uint8 (*NcsSecOCAlgorithm)\
    (AlgorithmInDataType keyRawIn, AlgorithmInDataType vinIn, AlgorithmOutDataType keyAuthOut);

static inline uint32 NCS_Remainder(uint8 data)
{
    return ((uint32)data % NCS_REMAIN_DIV);
}

static inline Std_ReturnType NCS_ParserInputCheck(const uint8 *inputDate, uint32 inputLen, uint32 lenExpected)
{
    if ((inputDate == NULL_PTR) || (inputLen != lenExpected)) {
        return E_NOT_OK;
    }
    return E_OK;
}

/* 将Key_ram转换为key_author */
uint8 NCS_Algorithm1802(AlgorithmInDataType keyRawIn, AlgorithmInDataType vinIn, AlgorithmOutDataType keyAuthOut);

#endif