/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.
 * Description: The Common public definitions of E2E
 * Create: 2019-06-17
 */

/**
 * @file
 *
 * @brief The Common public definitions of E2E
 */
#ifndef E2E_TYPE_DEFINE_H
#define E2E_TYPE_DEFINE_H

// At least one pointer parameter is a NULL pointer
#define E2E_E_INPUTERR_NULL 0x13U

// At least one input parameter is erroneous, e.g. out of range
#define E2E_E_INPUTERR_WRONG 0x17U

// An internal library error has occurred
// (e.g. error detected by program flow monitoring, violated invariant or postcondition)
#define E2E_E_INTERR 0x19U

// Function completed successfully
#define E2E_E_OK 0x00U

#define E2E_E_NOT_OK 0x01U

// Function executed in wrong state
#define E2E_E_WRONGSTATE 0x1AU

// The length of E2E header of each profiles
#define E2E_P01_HEADER_LENGTH 2U
#define E2E_P02_HEADER_LENGTH 2U
#define E2E_P04_HEADER_LENGTH 12U
#define E2E_P04M_HEADER_LENGTH 16U
#define E2E_P05_HEADER_LENGTH 3U
#define E2E_P06_HEADER_LENGTH 5U
#define E2E_P07_HEADER_LENGTH 20U
#define E2E_P11_HEADER_LENGTH 2U
#define E2E_P22_HEADER_LENGTH 2U
#define E2E_P44_HEADER_LENGTH 12U

#define E2E_SHIFT_FROM_BIT_TO_BYTE 3U
#define E2E_FROM_BIT_TO_BYTE 8U
/* AXIVION Next Line MisraC2012-2.5 :  It is defined for other function */
#define E2E_SHIFT_ONE_NIBBLE 4U
#define E2E_DATAIDLIST_LENGTH 16U

// Return value of E2Exf
#define E_SAFETY_SOFT_RUNTIMEERROR 0x77U
#define E_SAFETY_HARD_RUNTIMEERROR 0xFFU

// Return value of E2EXf_Inv
#define E_SAFETY_VALID_OK 0x00U
#define E_SAFETY_VALID_REP 0x01U
#define E_SAFETY_VALID_SEQ 0x02U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_VALID_CRC_ERR 0x03U
#define E_SAFETY_VALID_DID_ERR 0x0AU
#define E_SAFETY_VALID_DLEN_ERR 0x0BU
#endif
#define E_SAFETY_VALID_ERR 0x03U
#define E_SAFETY_VALID_NAV 0x04U
#define E_SAFETY_VALID_NND 0x05U
#define E_SAFETY_VALID_TMO 0x06U

#define E_SAFETY_DEINIT_OK 0x10U
#define E_SAFETY_DEINIT_REP 0x11U
#define E_SAFETY_DEINIT_SEQ 0x12U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_DEINIT_CRC_ERR 0x13U
#define E_SAFETY_DEINIT_DID_ERR 0x1AU
#define E_SAFETY_DEINIT_DLEN_ERR 0X1BU
#endif
#define E_SAFETY_DEINIT_ERR 0x13U
#define E_SAFETY_DEINIT_NAV 0x14U
#define E_SAFETY_DEINIT_NND 0x15U
#define E_SAFETY_DEINIT_TMO 0x16U

#define E_SAFETY_NODATA_OK 0x20U
#define E_SAFETY_NODATA_REP 0x21U
#define E_SAFETY_NODATA_SEQ 0x22U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_NODATA_CRC_ERR 0x23U
#define E_SAFETY_NODATA_DID_ERR 0x2AU
#define E_SAFETY_NODATA_DLEN_ERR 0x2BU
#endif
#define E_SAFETY_NODATA_ERR 0x23U
#define E_SAFETY_NODATA_NAV 0x24U
#define E_SAFETY_NODATA_NND 0x25U
#define E_SAFETY_NODATA_TMO 0x26U

#define E_SAFETY_INIT_OK 0x30U
#define E_SAFETY_INIT_REP 0x31U
#define E_SAFETY_INIT_SEQ 0x32U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_INIT_CRC_ERR 0x33U
#define E_SAFETY_INIT_DID_ERR 0x3AU
#define E_SAFETY_INIT_DLEN_ERR 0x3BU
#endif
#define E_SAFETY_INIT_ERR 0x33U
#define E_SAFETY_INIT_NAV 0x34U
#define E_SAFETY_INIT_NND 0x35U
#define E_SAFETY_INIT_TMO 0x36U

#define E_SAFETY_INVALID_OK 0x40U
#define E_SAFETY_INVALID_REP 0x41U
#define E_SAFETY_INVALID_SEQ 0x42U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_INVALID_CRC_ERR 0x43U
#define E_SAFETY_INVALID_DID_ERR 0x4AU
#define E_SAFETY_INVALID_DLEN_ERR 0x4BU
#endif
#define E_SAFETY_INVALID_ERR 0x43U
#define E_SAFETY_INVALID_NAV 0x44U
#define E_SAFETY_INVALID_NND 0x45U
#define E_SAFETY_INVALID_TMO 0x46U

#define E_SAFETY_INVALID_PERMANENT_OK 0X50U
#define E_SAFETY_INVALID_PERMANENT_REP 0X51U
#define E_SAFETY_INVALID_PERMANENT_SEQ 0X52U
#ifdef ENABLE_E2E_P04_EXERRCODE
#define E_SAFETY_INVALID_PERMANENT_CRC_ERR 0X53U
#define E_SAFETY_INVALID_PERMANENT_DID_ERR 0X5AU
#define E_SAFETY_INVALID_PERMANENT_DLEN_ERR 0X5BU
#endif
#define E_SAFETY_INVALID_PERMANENT_ERR 0X53U
#define E_SAFETY_INVALID_PERMANENT_NAV 0X54U
#define E_SAFETY_INVALID_PERMANENT_NND 0X55U
#define E_SAFETY_INVALID_PERMANENT_TMO 0X56U


#define STD_MESSAGETYPE_REQUEST 0x00U
/* AXIVION Next Line MisraC2012-2.5: It is not declaring a type */
#define STD_MESSAGETYPE_RESPONSE 0x01U

#define STD_MESSAGERESULT_OK 0x00U
/* AXIVION Next Line MisraC2012-2.5: It is not declaring a type */
#define STD_MESSAGERESULT_ERROR 0x01U

#endif

