/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.
 * Description  : LdCom module header file
 * Author: VOS
 * Create       : 2019-8-15
 */

#ifndef LDCOM_H
#define LDCOM_H

/* SWS_LDCOM_00020 */
#include "ComStack_Types.h"
#include "LdCom_Cfg.h"
#include "Dfs_Types.h"
#include "LdCom_Types.h"

#define LDCOM_START_SEC_CODE
#include "LdCom_MemMap.h"

/****************************************************************************************************
 * Macro
 ****************************************************************************************************/
#define LDCOM_AR_RELEASE_MAJOR_VERSION          4u
#define LDCOM_AR_RELEASE_MINOR_VERSION          4u
#define LDCOM_AR_RELEASE_REVISION_VERSION       0u

/* Vendor and module */
#define LDCOM_VENDOR_ID                          PLATFORM_VENDOR_ID
#define LDCOM_MODULE_ID                          49u
#define LDCOM_INSTANCE_ID                        0u

/* Component version information */
#define LDCOM_SW_MAJOR_VERSION                   3u
#define LDCOM_SW_MINOR_VERSION                   2u
#define LDCOM_SW_PATCH_VERSION                   224u

#if (!defined(LDCOM_CFG_SW_MAJOR_VERSION) || (LDCOM_CFG_SW_MAJOR_VERSION != LDCOM_SW_MAJOR_VERSION))
#error LdCom_Cfg.h major version not defined or mismatch.
#endif

#if (!defined(LDCOM_CFG_SW_MINOR_VERSION) || (LDCOM_CFG_SW_MINOR_VERSION != LDCOM_SW_MINOR_VERSION))
#error LdCom_Cfg.h minor version not defined or mismatch.
#endif

#if (!defined(LDCOM_CFG_SW_PATCH_VERSION) || (LDCOM_CFG_SW_PATCH_VERSION != LDCOM_SW_PATCH_VERSION))
#error LdCom_Cfg.h patch version not defined or mismatch.
#endif

#define LDCOM_BIT_SIZE16                                (16u)
#define LDCOM_DFS_POLLING_PDU_NUM                       (80u)

#define LDCOM_CALCULATE_ADD_PDU_NUM                     (15u)
#define LDCOM_DFS_TRANSMIT_FAIL_NUM                     (5u)

#if ((LDCOM_DEV_ERROR_DETECT == STD_ON) || (LDCOM_LOG_SUPPORT == STD_ON))
/* Development Error Codes for DET Support. SWS_LDCOM_00018 */
#define LDCOM_E_UNINIT                           (0x02u)
#define LDCOM_E_PARAM_POINTER                    (0x03u)
#define LDCOM_E_INVALID_PDU_SDU_ID               (0x04u)
#define LDCOM_E_INVALID_SIGNAL_ID                (0x05u)
#endif

#if (LDCOM_DFS_ENABLED == STD_ON)
#define LDCOM_DFS_OK                             (0x00u)
#define LDCOM_DFS_PARAM_POINTER_ERROR            (0x11u)
#define LDCOM_DFS_BUFFER_IN_SIZE_ERROR           (0x13u)
#define LDCOM_DFS_BUFFER_OUT_SIZE_ERROR          (0x14u)
#define LDCOM_DFS_RUN_ERROR                      (0x22u)
#define LDCOM_DFS_OPERATION_TYPE_ERROR           (0x31u)

#define LDCOM_DFS_OPEN                           (0x01u)
#define LDCOM_DFS_CLOSE                          (0x02u)
#define LDCOM_DFS_GET_DATA_BY_POLLING            (0x03u)
#define LDCOM_DFS_CALL_COUNT                     (0x0Bu)
#define LDCOM_DFS_ERROR_COUNT                    (0x0Cu)
#define LDCOM_DFS_TRANSMIT_FAIL_COUNT            (0x0Du)

#define LDCOM_DFS_POLLING_START_LENGTH           (4u)
#define LDCOM_DFS_PERIODIC_RECORD                (0x01u)
#endif /* LDCOM_DFS_ENABLED */

/* Service Id for reporting error */
#if (LDCOM_DFS_ENABLED == STD_ON)
#define LDCOM_SID_GETDFSDATA                     (0x01u)
#endif
#if LDCOM_VERSION_INFO_API != STD_OFF
#define LDCOM_SID_GETVERSIONINFO                 (0x03u)
#endif
#define LDCOM_SID_TRANSMIT                       (0x05u)
#if LDCOM_IFTX_ENABLED != STD_OFF
#define LDCOM_SID_TXCONFIRMATION                 (0x40u)
#endif
#if LDCOM_TRIGGERTX_ENABLED != STD_OFF
#define LDCOM_SID_TRIGGERTRANSMIT                (0x41u)
#endif
#if LDCOM_IFRX_ENABLED != STD_OFF
#define LDCOM_SID_RXINDICATION                   (0x42u)
#endif
#if LDCOM_TPTX_ENABLED != STD_OFF
#define LDCOM_SID_COPYTXDATA                     (0x43u)
#endif
#if LDCOM_TPRX_ENABLED != STD_OFF
#define LDCOM_SID_COPYRXDATA                     (0x44u)
#define LDCOM_SID_TPRXINDICATION                 (0x45u)
#define LDCOM_SID_STARTOFRECEPTION               (0x46u)
#endif
#if LDCOM_TPTX_ENABLED != STD_OFF
#define LDCOM_SID_TPTXCONFIRMATION               (0x48u)
#endif

/* Bit for reporting error */
#define LDCOM_BIT_TRANSMIT_INVALID_SIGNAL_ID                          (0u)
#define LDCOM_BIT_TRANSMIT_PDUINFO_NULLPTR                            (1u)
#if LDCOM_IFTX_ENABLED != STD_OFF
#define LDCOM_BIT_TXCONFIRMATION_INVALID_SIGNAL_ID                    (2u)
#endif
#if LDCOM_TRIGGERTX_ENABLED != STD_OFF
#define LDCOM_BIT_TRIGGERTRANSMIT_INVALID_SIGNAL_ID                   (3u)
#define LDCOM_BIT_TRIGGERTRANSMIT_PDUINFO_NULLPTR                     (4u)
#define LDCOM_BIT_TRIGGERTRANSMIT_CALLBACK_NULLPTR_ERROR              (5u)
#endif
#if LDCOM_IFRX_ENABLED != STD_OFF
#define LDCOM_BIT_RXINDICATION_INVALID_SIGNAL_ID                      (6u)
#define LDCOM_BIT_RXINDICATION_PDUINFO_NULLPTR                        (7u)
#define LDCOM_BIT_RXINDICATION_CALLBACK_NULLPTR_ERROR                 (8u)
#endif
#if LDCOM_TPTX_ENABLED != STD_OFF
#define LDCOM_BIT_COPYTXDATA_INVALID_SIGNAL_ID                        (9u)
#define LDCOM_BIT_COPYTXDATA_PDUINFO_NULLPTR                          (10u)
#define LDCOM_BIT_COPYTXDATA_CALLBACK_NULLPTR_ERROR                   (11u)
#endif
#if LDCOM_TPRX_ENABLED != STD_OFF
#define LDCOM_BIT_COPYRXDATA_INVALID_SIGNAL_ID                        (12u)
#define LDCOM_BIT_COPYRXDATA_PDUINFO_NULLPTR                          (13u)
#define LDCOM_BIT_COPYRXDATA_CALLBACK_NULLPTR_ERROR                   (14u)
#define LDCOM_BIT_TPRXINDICATION_INVALID_SIGNAL_ID                    (15u)
#define LDCOM_BIT_TPRXINDICATION_CALLBACK_NULLPTR_ERROR               (16u)
#define LDCOM_BIT_STARTOFRECEPTION_INVALID_SIGNAL_ID                  (17u)
#define LDCOM_BIT_STARTOFRECEPTION_CALLBACK_NULLPTR_ERROR             (18u)
#endif
#if LDCOM_TPTX_ENABLED != STD_OFF
#define LDCOM_BIT_TPTXCONFIRMATION_INVALID_SIGNAL_ID                  (19u)
#endif

#ifndef LDCOM_LOCAL
#define LDCOM_LOCAL static
#endif

#ifndef LDCOM_APPL_CONST
#define LDCOM_APPL_CONST
#endif

#ifndef LDCOM_VAR
#define LDCOM_VAR
#endif

#define LDCOM_STOP_SEC_CODE
#include "LdCom_MemMap.h"

/****************************************************************************************************
 * Extern function for other module
 ****************************************************************************************************/
#define LDCOM_START_SEC_DFS_CODE
#include "LdCom_MemMap.h"
FUNC(Std_ReturnType, SD_CODE) LdCom_DfsServiceDataAccessFunc(
    VAR(uint8, AUTOMATIC) operationType,
    P2VAR(Dfs_ServiceDataType, AUTOMATIC, LDCOM_APPL_DATA) dataHandler,
    P2VAR(uint8, AUTOMATIC, LDCOM_APPL_DATA) errorCode);
#define LDCOM_STOP_SEC_DFS_CODE
#include "LdCom_MemMap.h"

#define LDCOM_START_SEC_CODE
#include "LdCom_MemMap.h"
/* SWS_LDCOM_00022 */
FUNC(void, LDCOM_CODE) LdCom_Init(P2CONST(LdCom_ConfigType, AUTOMATIC, LDCOM_APPL_CONST) config);

/* SWS_LDCOM_00023 */
FUNC(void, LDCOM_CODE) LdCom_DeInit(void);

#if LDCOM_VERSION_INFO_API != STD_OFF
/* SWS_LDCOM_00024 */
FUNC(void, LDCOM_CODE) LdCom_GetVersionInfo(P2VAR(Std_VersionInfoType, AUTOMATIC, LDCOM_APPL_DATA) versioninfo);
#endif

/* SWS_LDCOM_00026 */
FUNC(Std_ReturnType, LDCOM_CODE) LdCom_Transmit(
    VAR(PduIdType, AUTOMATIC) Id,
    P2CONST(PduInfoType, AUTOMATIC, LDCOM_APPL_CONST) InfoPtr
);

/* SWS_LDCOM_00033 */
#if LDCOM_TRIGGERTX_ENABLED != STD_OFF
FUNC(Std_ReturnType, LDCOM_CODE) LdCom_TriggerTransmit(
    VAR(PduIdType, AUTOMATIC) TxPduId,
    P2VAR(PduInfoType, AUTOMATIC, LDCOM_APPL_DATA) PduInfoPtr
);
#endif

#if LDCOM_TPTX_ENABLED != STD_OFF
/* SWS_LDCOM_00027 */
FUNC(BufReq_ReturnType, LDCOM_CODE) LdCom_CopyTxData(
    VAR(PduIdType, AUTOMATIC) id,
    P2CONST(PduInfoType, AUTOMATIC, LDCOM_APPL_CONST) info,
    P2CONST(RetryInfoType, AUTOMATIC, LDCOM_APPL_CONST) retry,
    P2VAR(PduLengthType, AUTOMATIC, LDCOM_APPL_DATA) availableDataPtr
);

/* SWS_LDCOM_00028 */
FUNC(void, LDCOM_CODE) LdCom_TpTxConfirmation(
    VAR(PduIdType, AUTOMATIC) id,
    VAR(Std_ReturnType, AUTOMATIC) result
);
#endif

#if LDCOM_TPRX_ENABLED != STD_OFF
/* SWS_LDCOM_00029 */
FUNC(BufReq_ReturnType, LDCOM_CODE) LdCom_StartOfReception(
    VAR(PduIdType, AUTOMATIC) id,
    P2CONST(PduInfoType, AUTOMATIC, LDCOM_APPL_CONST) info,
    VAR(PduLengthType, AUTOMATIC) TpSduLength,
    P2VAR(PduLengthType, AUTOMATIC, LDCOM_APPL_DATA) bufferSizePtr
);

/* SWS_LDCOM_00030 */
FUNC(BufReq_ReturnType, LDCOM_CODE) LdCom_CopyRxData(
    VAR(PduIdType, AUTOMATIC) id,
    P2CONST(PduInfoType, AUTOMATIC, LDCOM_APPL_CONST) info,
    P2VAR(PduLengthType, AUTOMATIC, LDCOM_APPL_DATA) bufferSizePtr
);

/* SWS_LDCOM_00031 */
FUNC(void, LDCOM_CODE) LdCom_TpRxIndication(
    VAR(PduIdType, AUTOMATIC) id,
    VAR(Std_ReturnType, AUTOMATIC) result
);
#endif

#if LDCOM_IFRX_ENABLED != STD_OFF
/* SWS_LDCOM_00032 */
FUNC(void, LDCOM_CODE) LdCom_RxIndication(
    VAR(PduIdType, AUTOMATIC) RxPduId,
    P2CONST(PduInfoType, AUTOMATIC, LDCOM_APPL_CONST)PduInfoPtr
);
#endif

#if LDCOM_IFTX_ENABLED != STD_OFF
/* SWS_LDCOM_00056 */
FUNC(void, LDCOM_CODE) LdCom_TxConfirmation(
    VAR(PduIdType, AUTOMATIC) TxPduId,
    VAR(Std_ReturnType, AUTOMATIC) result
);
#endif
#define LDCOM_STOP_SEC_CODE
#include "LdCom_MemMap.h"
#endif
