/**************************************************************************************
 * Copyright (c) Huawei Technologies Co., Ltd. 2019-2019. All rights reserved.
 * Description: The Header file of Libc Module file
 * Author: VOS
 * Create: 2019-11-27
 *
 **************************************************************************************/
#ifndef QN_LIBC_UTIL_H
#define QN_LIBC_UTIL_H

/** The NULL pointer */
#if (!defined(NULL))
#if (!defined(__cplusplus))
#define NULL ((void *)0)
#else   /* C++ */
#define NULL 0
#endif  /* C++ */
#endif  /* NULL */

typedef unsigned long qn_size_t;

/** \addtogroup safetyos_libc
 *  @{
 */
/**
* @req{ SAR-VOS-LIBC-001,
* provide memcpy funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] dest destination data address
* @param [in] src source data address
* @param [in] n data length
*
* @return the function returns the destination data address
*/
void *qn_memcpy(void *dest, const void *src, qn_size_t n);

/**
* @req{ SAR-VOS-LIBC-002,
* provide memset funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] s memset start address
* @param [in] c memset data
* @param [in] n data length
*
* @return the function returns the start data address
*/
void *qn_memset(void *s, int c, qn_size_t n);

/**
* @req{ SAR-VOS-LIBC-005,
* provide strlen funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] s string address
*
* @return the function returns the length of this string
*/
qn_size_t qn_strlen(const char *s);

/**
* @req{ SAR-VOS-LIBC-007,
* provide strnlen funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] s string address
* @param [in] n max calc string length
*
* @return the function returns the length of this string
*/
qn_size_t qn_strnlen(const char *s, qn_size_t n);

/**
* @req{ SAR-VOS-LIBC-004,
* provide strcpy funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] dst destination string address
* @param [in] src source string address
*
* @return the function returns the destination string address
*/
char *qn_strcpy(char *dst, const char *src);

/**
* @req{ SAR-VOS-LIBC-006,
* provide strncpy funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] dst destination string address
* @param [in] src source string address
* @param [in] count string copy length
*
* @return the function returns the destination string address
*/
char *qn_strncpy(char *dst, const char *src, qn_size_t count);

/**
* @req{ SAR-VOS-LIBC-003,
* provide strcmp funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] s1 string1 address
* @param [in] s2 string2 address
*
* @return the function returns the compare of s1 and s2
*/
int qn_strcmp(const char *s1, const char *s2);

/**
* @req{ SAR-VOS-LIBC-003,
* provide strncmp funciton,
* D,
* SDR-VOS-LIB-0001
* }
*
* @param [in] s1 string1 address
* @param [in] s2 string2 address
* @param [in] n compare count
*
* @return the function returns the compare of s1 and s2
*/
int qn_strncmp(const char *s1, const char *s2, qn_size_t n);

/**
* @req{ R-VOS-LIB-LIBC-30001,
* support libc random function,
* D,
* DR-VOS-LIB-LIBC-300001
* }
*
* @param [in] seed init
*
* @no return
*/
void qn_srand(unsigned int seed);
/**
* @req{ R-VOS-LIB-LIBC-30001,
* support libc random function,
* D,
* DR-VOS-LIB-LIBC-300001
* }
*
* @no param
* @return random value
*/
unsigned int qn_rand(void);
/** @} */

#endif
