/*******************************************************************************
**                                                                            **
** Copyright (C) Infineon Technologies (2017)                                 **
**                                                                            **
** All rights reserved.                                                       **
**                                                                            **
** This document contains proprietary information belonging to Infineon       **
** Technologies. Passing on and copying of this document, and communication   **
** of its contents is not permitted without prior written authorization.      **
**                                                                            **
********************************************************************************
**                                                                            **
**  FILENAME  : Lin_17_AscLin_Cfg.h                                           **
**                                                                            **
**  VERSION   : 2.0.0                                                         **
**                                                                            **
**  DATE, TIME: 2020-01-15, 14:59:36                                          **
**                                                                            **
**  GENERATOR : Build b170330-0431                                            ** 
**                                                                            **
**  BSW MODULE DECRIPTION : Lin.bmd                                           **
**                                                                            **
**  VARIANT   : Variant PB                                                    **
**                                                                            **
**  PLATFORM  : Infineon AURIX2G                                              **
**                                                                            **
**  AUTHOR    : DL-AUTOSAR-Engineering                                        **
**                                                                            **
**  VENDOR    : Infineon Technologies                                         **
**                                                                            **
**  DESCRIPTION  : Lin configuration generated out of ECUC file               **
**                                                                            **
**  SPECIFICATION(S) : Specification of Lin Driver, AUTOSAR Release 4.2.2     **
**                                                                            **
**  MAY BE CHANGED BY USER : no                                               **
**                                                                            **
*******************************************************************************/

#ifndef LIN_17_ASCLIN_CFG_H
#define LIN_17_ASCLIN_CFG_H



/* AUTOSAR specification version numbers */
#define LIN_17_ASCLIN_AR_RELEASE_MAJOR_VERSION  (4U)
#define LIN_17_ASCLIN_AR_RELEASE_MINOR_VERSION  (2U)
#define LIN_17_ASCLIN_AR_RELEASE_PATCH_VERSION  (2U)


/* Vendor specific implementation version information */
#define LIN_17_ASCLIN_SW_MAJOR_VERSION  (10U)
#define LIN_17_ASCLIN_SW_MINOR_VERSION  (10U)
#define LIN_17_ASCLIN_SW_PATCH_VERSION  (0U)

/*******************************************************************************
**                      Includes                                              **
*******************************************************************************/


/*******************************************************************************
**                      Global Macro Definitions                              **
*******************************************************************************/

/*
                     Container : GeneralConfiguration
*/

/*
Configuration: LIN_17_ASCLIN_DEV_ERROR_DETECT
- if STD_ON, DET is Enabled 
- if STD_OFF, DET is Disabled 
*/
#define LIN_17_ASCLIN_DEV_ERROR_DETECT (STD_ON)

/*
Configuration: LIN_17_ASCLIN_VERSION_INFO_API
- if STD_ON, Lin_17_AscLin_GetVersionInfo() Api is Enabled 
- if STD_OFF, Lin_17_AscLin_GetVersionInfo() Api is Disabled 
*/
#define LIN_17_ASCLIN_VERSION_INFO_API (STD_OFF)

/* Instance Id of Lin module instance */
#define LIN_17_ASCLIN_INDEX (0)

/* Maximum number of ASCLIN Hw modules available  */
#define LIN_17_ASCLIN_MAX_HW_UNIT (12)

/* Maximum number of LIN Channels configured */
#define LIN_17_ASCLIN_MAXIMUM_CHANNEL (3)

/*
Configuration: LIN_17_ASCLIN_CLC
- if 0x0, ASCLIN module sleep upon request is Enabled 
- if 0x8, ASCLIN module sleep upon request is Disabled 
*/
#define LIN_17_ASCLIN_CLC (0x8)

/* Identifies the the Rx alternate pin selection for a channel */
#define LIN_17_ASCLIN_SELECT_A (0x0)
#define LIN_17_ASCLIN_SELECT_B (0x1)
#define LIN_17_ASCLIN_SELECT_C (0x2)
#define LIN_17_ASCLIN_SELECT_D (0x3)
#define LIN_17_ASCLIN_SELECT_E (0x4)
#define LIN_17_ASCLIN_SELECT_F (0x5)
#define LIN_17_ASCLIN_SELECT_G (0x6)
#define LIN_17_ASCLIN_SELECT_H (0x7)

/* Identifies the the ASCLINx for a channel */
#define LIN_17_ASCLIN0 (0U)
#define LIN_17_ASCLIN1 (1U)
#define LIN_17_ASCLIN2 (2U)
#define LIN_17_ASCLIN3 (3U)
#define LIN_17_ASCLIN4 (4U)
#define LIN_17_ASCLIN5 (5U)
#define LIN_17_ASCLIN6 (6U)
#define LIN_17_ASCLIN7 (7U)
#define LIN_17_ASCLIN8 (8U)
#define LIN_17_ASCLIN9 (9U)
#define LIN_17_ASCLIN10 (10U)
#define LIN_17_ASCLIN11 (11U)

/* Generating list of offset addresses defined in register file for all LIN 
   kernels */
#define LIN_17_ASCLIN_REGADDR  &MODULE_ASCLIN0, \
  &MODULE_ASCLIN1,  &MODULE_ASCLIN2,  &MODULE_ASCLIN3, \
  &MODULE_ASCLIN4,  &MODULE_ASCLIN5,  &MODULE_ASCLIN6, \
  &MODULE_ASCLIN7,  &MODULE_ASCLIN8,  &MODULE_ASCLIN9, \
  &MODULE_ASCLIN10,  &MODULE_ASCLIN11 
/*
Configuration: LIN_17_ASCLIN_CSRREG_CLKSEL
- if 0x2, ASCLIN peripheral frequency for fast mode is selected 
- if 0x4, ASCLIN peripheral frequency for slow mode is selected 
*/
#define LIN_17_ASCLIN_CSRREG_CLKSEL (0x4)

#define LIN_17_ASCLIN_INIT_DEINIT_API_MODE (LIN_17_ASCLIN_MCAL_SUPERVISOR_MODE)

#define LIN_17_ASCLIN_MCAL_SUPERVISOR_MODE (STD_ON)

#define LIN_17_ASCLIN_MCAL_USER1_MODE (STD_OFF)

#define LIN_17_ASCLIN_INTERRUPT_DISABLED (STD_OFF)

/*
  Lin Channel : (LinChannel_0)
*/
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
#ifndef Lin_17_AscLinConf_LinChannel_LinChannel_0
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* <!-- [cover parentID={F7E0ED21-7774-45fb-9AEC-47490C5AE1F9}]
    [/cover] --> */
#define Lin_17_AscLinConf_LinChannel_LinChannel_0          (0U) 
#endif 

/*
  Lin Channel : (LinChannel_1)
*/
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
#ifndef Lin_17_AscLinConf_LinChannel_LinChannel_1
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* <!-- [cover parentID={F7E0ED21-7774-45fb-9AEC-47490C5AE1F9}]
    [/cover] --> */
#define Lin_17_AscLinConf_LinChannel_LinChannel_1          (1U) 
#endif 

/*
  Lin Channel : (LinChannel_2)
*/
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
#ifndef Lin_17_AscLinConf_LinChannel_LinChannel_2
/* MISRA2012_RULE_5_1_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_2_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_4_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* MISRA2012_RULE_5_5_JUSTIFICATION: External identifiers going beyond 32 chars.
  in generated code due to Autosar Naming constraints.*/
/* <!-- [cover parentID={F7E0ED21-7774-45fb-9AEC-47490C5AE1F9}]
    [/cover] --> */
#define Lin_17_AscLinConf_LinChannel_LinChannel_2          (2U) 
#endif 


/*
Configuration: LIN_17_ASCLIN_GLOBAL_CHANNEL_WAKEUP_SUPPORT
- if STD_ON, LinChannelWakeupSupport is enabled for atleast 1 channel 
- if STD_OFF, LinChannelWakeupSupport is not enabled for atleast 1 channel 
*/
#define LIN_17_ASCLIN_GLOBAL_CHANNEL_WAKEUP_SUPPORT (STD_ON)


/*******************************************************************************
**                      Global Type Definitions                               **
*******************************************************************************/

/*******************************************************************************
**                      Global Constant Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                      Global Variable Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                      Global Function Declarations                          **
*******************************************************************************/

/*******************************************************************************
**                      Global Inline Function Definitions                    **
*******************************************************************************/
#endif /* LIN_17_ASCLIN_CFG_H */

