/**
 * \file       Crypto_11_Hsm_Helpers.h
 * \copyright  (c) ESCRYPT GmbH, Bochum, Germany 2019.
 *             All rights reserved, also regarding any disposal, exploitation, reproduction, editing, distribution,
 *             as well as in the event of applications for industrial property rights.
 * \brief      General helper functions for crypto driver code
 *
 */

#ifndef CRYPTO_11_HSM_HELPERS_H
#define CRYPTO_11_HSM_HELPERS_H

/* Global PRQA suppressions */
/* PRQA S 3214 EOF #Suppressed because of the ASR memmap concept */
/* PRQA S 0857 EOF #Deviation ID directive_1.1_0857 */
/* PRQA S 5002 EOF #Suppressed as header file names are defined by ASR. */

#include <Csm_Types.h>
#include <Crypto_11_Hsm_Internal.h>

#define CRYPTO_11_HSM_START_SEC_CODE
/* PRQA S 5087 1 #File inclusion is OK for memory mapping header file */
#include <Crypto_11_Hsm_MemMap.h>

/**
 * \req [$DD 75]
 * [$Satisfies $SWS_Crypto 00136][$Satisfies $SWS_Crypto 00195]
 * \brief         - Convert ecy_hsm_Csai_ErrorT -> Std_ReturnType
 * \note          - This function is called by \ref Crypto_11_Hsm_ReportIfRuntimeError
 *
 * \param[in] csaiErr - CSAI layer error to convert
 *
 * \return            - Currently returns the following errors:
 *
 * \retval E_OK                   - no error
 * \retval E_NOT_OK               - unspecified error
 * \retval CRYPTO_E_SMALL_BUFFER  - output buffer too small
 */
FUNC(Std_ReturnType, CRYPTO_11_HSM_CODE) Crypto_11_Hsm_CsaiErrorToStdReturn(
    CONST(ecy_hsm_Csai_ErrorT, AUTOMATIC) csaiErr);

/**
 * \req [$DD 76]
 * [$Satisfies $SWS_Crypto 00136][$Satisfies $SWS_Crypto 00195]
 * \brief Check if error has a runtime equivalent, and if so, report it
 *
 * \param[in] DetApiId - module code for DET reporting
 * \param[in] error    - error to parse
 */
FUNC(void, CRYPTO_11_HSM_CODE) Crypto_11_Hsm_ReportIfRuntimeError(
    CONST(uint8, AUTOMATIC) DetApiId,
    CONST(Std_ReturnType, AUTOMATIC) error);

#define CRYPTO_11_HSM_STOP_SEC_CODE
/* PRQA S 5087 1 #File inclusion is OK for memory mapping header file */
#include <Crypto_11_Hsm_MemMap.h>

#endif /* CRYPTO_11_HSM_HELPERS_H */
