/**
 * \file
 * \internal
 * \copyright (c) ESCRYPT GmbH, Bochum, Germany 2019. All rights reserved, also regarding any disposal, exploitation, reproduction, editing, distribution, as well as in the event of applications for industrial property rights.
 */

/* Global QA-C suppression */
/* PRQA S 0776, 0778 EOF #Deviation ID directive_1.1_0776_0778 */
/* PRQA S 0292 EOF #Deviation ID directive_1.1_0292 */
/* PRQA S 0857 EOF #Deviation ID directive_1.1_0857 */
/* PRQA S 2053 EOF #Deviation ID rule_18.8_2053 */
/* PRQA S 3214 EOF #Suppressed because of the ASR memmap concept */
/* PRQA S 2000 EOF #Suppressed for simplicity. Not necessary having else statement is allowed. */
/* PRQA S 5002 EOF #Suppressed as header file names are defined by ASR. */

#ifndef CRYPTO_11_HSM_INTERNAL_H
#define CRYPTO_11_HSM_INTERNAL_H

#include <Csm_Types.h>
#include <Crypto_11_Hsm_Cfg.h>
#include <Crypto_11_Hsm_Services.h>
#include <Crypto_11_Hsm.h>

#include <ecy_hsm_proxy.h>
#include <ecy_hsm_csai_keys.h>
#include <ecy_hsm_csai_dh.h>
#include <ecy_hsm_csai_key_exchange.h>

/* PRQA S 3453, 3472 ++ #No need to use functions instead of the macros below */
/* PRQA S 4800 ++ #Macros do not need to conform to the naming rule as they are only visible internally */
#define HsmKeyState(pHsmKey)                    ((pHsmKey)->pHsmKeyRuntime->keyState)
#define HsmKeyUsingSessionsCount(pHsmKey)       ((pHsmKey)->pHsmKeyRuntime->numOfSessionsUsingTheKey)
#define HsmKeyLinkedKeyToRelease(pHsmKey)       ((pHsmKey)->pHsmKeyRuntime->pHsmKeyToRelease)
#define HsmKeyHandle(pHsmKey)                   ((pHsmKey)->pHsmKeyRuntime->keyHandle)
#define HsmKeyJobHandle(pHsmKey)                ((pHsmKey)->pHsmKeyRuntime->hJob)
#define HsmKeyTimeoutMaybeLoaded(pHsmKey)       ((pHsmKey)->pHsmKeyRuntime->timeoutMaybeLoaded)
#define GetHsmKeyId(pHsmKey)                    ((pHsmKey)->pHsmKeyConfig->HsmKeyId)
#define GetHsmKeyProperties(pHsmKey)            ((pHsmKey)->pHsmKeyConfig->KeyProperties)
#define GetHsmKeyType(pHsmKey)                  ((pHsmKey)->pHsmKeyConfig->HsmKeyType)
#define GetHsmKeyMirroring(pHsmKey)             ((pHsmKey)->pHsmKeyConfig->RamMirroring)
#define IsHsmKeyPersisted(pHsmKey)              ((pHsmKey)->pHsmKeyConfig->pElement->Persist)
#define GetHsmKeyFormat(pHsmKey)                ((pHsmKey)->pHsmKeyConfig->pElement->Format)
#define GetHsmKeySize(pHsmKey)                  ((pHsmKey)->pHsmKeyConfig->pElement->Size)
/* PRQA S 4800, 3453 -- */

#ifndef CRYPTO_11_HSM_CONFIG_ENABLE_ASSERT
#define CRYPTO_11_HSM_CONFIG_ENABLE_ASSERT STD_OFF
#endif

#if (CRYPTO_11_HSM_CONFIG_ENABLE_ASSERT == STD_ON)
#include <Crypto_11_Hsm_Assert.h>
/* PRQA S 5209, 5003 3 #This macro is just active for debugging purposes */
#define CRYPTO_11_HSM_ASSERT(x) Crypto_11_Hsm_Assert((x), __FILE__, __LINE__)
#else
#define CRYPTO_11_HSM_ASSERT(x)
#endif

#if (CRYPTO_11_HSM_CONFIG_HAS_SHE_SERVICES == STD_ON)
#define CRYPTO_11_HSM_SHE_TIMEOUT_SUBINDICES                2u
#define CRYPTO_11_HSM_SHE_SUPPORTED_SERVICE_TIMEOUT_CNT     7u
#endif

/* SHE callout error codes */
#define CRYPTO_11_HSM_ERC_NO_ERROR            0x00u   /* No error has occurred, command will be executed */
#define CRYPTO_11_HSM_ERC_SEQUENCE_ERROR      0x01u   /* Error in sequence of commands or sub commands. */
#define CRYPTO_11_HSM_ERC_BUSY                0x02u   /* Error, SHE module is still busy with another function. */
#define CRYPTO_11_HSM_ERC_KEY_NOT_AVAILABLE   0x10u   /* Error, the key is not available, e.g. locked. */
#define CRYPTO_11_HSM_ERC_KEY_INVALID         0x11u   /* Error, the key is not valid for the operation. */
#define CRYPTO_11_HSM_ERC_KEY_EMPTY           0x12u   /* Error, attempt to use a key that is not initialized. */
#define CRYPTO_11_HSM_ERC_NO_SECURE_BOOT      0x20u   /* Error, conditions for a secure boot process are not met or function changing the boot status is called without secure booting or after finishing the secure boot process. */
#define CRYPTO_11_HSM_ERC_KEY_WRITE_PROTECTED 0x30u   /* Error, key update attempted on write protected key or when an attempt is made to activate the debugger when a key is write protected */
#define CRYPTO_11_HSM_ERC_KEY_UPDATE_ERROR    0x31u   /* Error, the key update did not succeed due to errors in verification of the protocol messages.*/
#define CRYPTO_11_HSM_ERC_RNG_SEED            0x40u   /* Returned by SHE_Rnd if the seed has not been initialized before. */
#define CRYPTO_11_HSM_ERC_MEMORY_FAILURE      0x50u   /* Error, underlying memory technology registered a fault. */
#define CRYPTO_11_HSM_ERC_NO_DEBUGGING        0x60u   /* Error, internal debugging is not possible because the challenge response authentication did not complete successfully. */
#define CRYPTO_11_HSM_ERC_GENERAL_FAILURE     0xFFu   /* Error, which is not covered by any other specific error code. */
#define CRYPTO_11_HSM_ERC_INVALID             0xFFFFFFFFu   /* Invalid value used for initialization */

#define CRYPTO_11_HSM_BITS_PER_BYTE                 8u
#define CRYPTO_11_HSM_SHE_AES_BLOCK_SIZE_BYTES      (SHE_AES_BLOCK_SIZE_BYTES)
/* PRQA S 3383 1 #Wraparound is ensured for this arithmetic operation */
#define CRYPTO_11_HSM_SHE_AES_BLOCK_SIZE_BITS       (SHE_AES_BLOCK_SIZE_BYTES * CRYPTO_11_HSM_BITS_PER_BYTE)

/* Definition of key element bit lengths for ECC public keys and key pairs */
#define CRYPTO_11_HSM_ECDSA_256_PRIVATE_BIT_LENGTH  256u
#define CRYPTO_11_HSM_ECDSA_384_PRIVATE_BIT_LENGTH  384u
#define CRYPTO_11_HSM_ECDSA_256_PUBLIC_BIT_LENGTH   (2*CRYPTO_11_HSM_ECDSA_256_PRIVATE_BIT_LENGTH) /* concatenation of x and y coordinates */
#define CRYPTO_11_HSM_ECDSA_384_PUBLIC_BIT_LENGTH   (2*CRYPTO_11_HSM_ECDSA_384_PRIVATE_BIT_LENGTH)

#define CRYPTO_11_HSM_EDDSA_KEY_SIZE_BIT_LENGTH     256u
#define CRYPTO_11_HSM_PK_TO_PUBKEY_MULTIPLIER    2U

#define CRYPTO_11_HSM_KEY_EXCHANGE_PUBKEY_BUFFER_SIZE       96U /* For SECP-384 public key */
#define CRYPTO_11_HSM_KEY_EXCHANGE_PRIVKEY_BUFFER_SIZE      (CRYPTO_11_HSM_KEY_EXCHANGE_PUBKEY_BUFFER_SIZE >> 1U)
#define CRYPTO_11_HSM_MAXIMUM_SUPPORTED_PUB_KEY_LENGTH      CRYPTO_11_HSM_KEY_EXCHANGE_PUBKEY_BUFFER_SIZE

/* There is no need to have the init priority configurable as there is no other job processing possible during init time */
#define CRYPTO_11_HSM_INIT_PRIORITY              ecy_hsm_CSAI_PRIO_HIGH

/* CRYPTO_11_HSM_VENDOR_ID_30_STACK_USED is defined if the stack is a tested delivery from AUTOSAR vendor ID 30 (dec)
 * CRYPTO_11_HSM_USE_V4_3_0_JOBTYPE_FIELD_NAMES is defined as STD_ON if some portability changes are needed for a v4.3.0 stack */
#if defined(CRYPTO_11_HSM_VENDOR_ID_30_STACK_USED) || (CRYPTO_11_HSM_USE_V4_3_0_JOBTYPE_FIELD_NAMES == STD_ON)
#define CRYPTO_11_HSM_JOBSTATE state
#else
#define CRYPTO_11_HSM_JOBSTATE jobState
#endif

#if (CRYPTO_11_HSM_USE_V4_3_0_JOBTYPE_FIELD_NAMES == STD_ON)
#define CRYPTO_11_HSM_JOBPRIMITIVEINPUTOUTPUT PrimitiveInputOutput
#else
#define CRYPTO_11_HSM_JOBPRIMITIVEINPUTOUTPUT jobPrimitiveInputOutput
#endif

/* Define own uint32 max, as not all BSW have it defined in Platform_Types.h */
#define CRYPTO_11_HSM_UINT32_MAX 0xFFFFFFFFU

/**
 * Defines for the Key release strategies
 */
/**\brief Always release the key with the highest Id = Lowest prio */
#define CRYPTO_11_HSM_KEY_RELEASE_STRATEGY_LOW_PRIO_FIRST                   0u
/**\brief First try to release RSA keys for RSA keys etc, with highest Id */
#define CRYPTO_11_HSM_KEY_RELEASE_STRATEGY_LOW_PRIO_FIRST_PREFER_SAME_TYPE  1u
/**\brief Keep a fixed amount of AES keys and release the others when not in use */
#define CRYPTO_11_HSM_KEY_RELEASE_STRATEGY_ONLY_AES_KEYS                    2u
/**\brief Release all keys when not in use*/
#define CRYPTO_11_HSM_KEY_RELEASE_STRATEGY_RELEASE_ALL                      3u

typedef enum
{
    DRIVER_CONFIG_STATE_UNINIT = 0,     /* UNINIT must be 0 for initialisation in a 'CLEARED' memory section */
    DRIVER_CONFIG_STATE_FAIL,
    DRIVER_CONFIG_STATE_SUCCESS,
#if (CRYPTO_11_HSM_PRE_CONFIGURED == STD_OFF)
    DRIVER_CONFIG_STATE_WAITING_FOR_BOOTED,
    DRIVER_CONFIG_STATE_WAITING_FOR_APP_MODE,
#endif
    DRIVER_CONFIG_STATE_OPEN_SESSIONS,
    DRIVER_STATE_HSM_LOCKED
} DriverState;

/* These enums are individually defined for clarity as they are used by value (as array indices) */
typedef enum
{
    DRIVER_OBJECT_STATE_IDLE = 0u,
    DRIVER_OBJECT_STATE_WAITING_TO_LOAD_KEY = 1u,
    DRIVER_OBJECT_STATE_KEY_LOAD_CANCELLED = 2u,
    DRIVER_OBJECT_STATE_PROCESSING_STANDARD = 3u,
    DRIVER_OBJECT_STATE_WAITING_FOR_INPUT = 4u,
    DRIVER_OBJECT_STATE_PROCESSING_CANCELLATION = 5u,
    DRIVER_OBJECT_STATE_PROCESSING_LAST_BLOCK = 6u,
    DRIVER_OBJECT_STATES_COUNT = 7u
} DriverObjectState;

typedef struct
{
    /**< Flag to indicate that job cancellation was requested (at the time when cancellation could not be started). */
    boolean cancelJobFlag;
    /**< JobId to be cancelled  */
    uint32 jobId;
} DriverObjectCancelMsgT;

typedef struct
{
    ecy_hsm_Csai_SessionHandleT hSession;
    ecy_hsm_Csai_JobHandleT hJob;
    Crypto_JobType* job;
    DriverObjectState state;
    Crypto_11_Hsm_ServiceData data;
    DriverObjectCancelMsgT cancelMsg;
    uint32 timerId;
    /**< Flag to indicate that a key was locked and will need to be released at the end of current job processing */
    boolean keyLocked;
    /**< Flag to indicate that a object has been locked for multitasking/multiprocessing */
    boolean objectLocked;
} DriverObjectData;

/**
 * \brief Configuration of a CryptoPrimitive
 */
typedef struct
{
    Crypto_AlgorithmFamilyType AlgorithmFamily; /**< Determines the algorithm family used for the crypto service */
    Crypto_AlgorithmFamilyType AlgorithmSecondaryFamily; /**< Determines the algorithm secondary family used for the crypto service */
    Crypto_AlgorithmModeType AlgorithmMode; /**< Determines the algorithm mode used for the crypto service */
    Crypto_ServiceInfoType Service; /**< Determines the crypto service used for defining the capabilities */
} Crypto_11_Hsm_Config_Primitive;

/**
 * \brief Configuration of a CryptoDriverObject
 */
typedef struct
{
    CONST(boolean, AUTOMATIC) Primitives[CRYPTO_11_HSM_CONFIG_CRYPTO_PRIMITIVE_COUNT]; /**< Refers to primitive in the CRYPTO. The CryptoPrimitive is a pre-configured container of the crypto service that shall be used. */
} Crypto_11_Hsm_Config_DriverObject;

/**
 * \brief
 */
typedef enum
{
    CRYPTO_11_HSM_KE_FORMAT_BIN_OCTET = 0x01,
    CRYPTO_11_HSM_KE_FORMAT_BIN_SHEKEYS = 0x02,
    CRYPTO_11_HSM_KE_FORMAT_BIN_IDENT_PRIVATEKEY_PKCS8 = 0x03,
    CRYPTO_11_HSM_KE_FORMAT_BIN_IDENT_PUBLICKEY = 0x04,
    CRYPTO_11_HSM_KE_FORMAT_BIN_RSA_PRIVATEKEY = 0x05,
    CRYPTO_11_HSM_KE_FORMAT_BIN_RSA_PUBLICKEY = 0x06,
    CRYPTO_11_HSM_KE_FORMAT_BIN_CERT_X509_V3 = 0x07,
    CRYPTO_11_HSM_KE_FORMAT_BIN_CERT_CVC = 0x08
} Crypto_11_Hsm_KeyElement_Format;

/**
 */
typedef enum
{
    CRYPTO_11_HSM_RA_DENIED = 0x01, /**< key element cannot be read from outside the Crypto Driver */
    CRYPTO_11_HSM_RA_INTERNAL_COPY = 0x02, /**< key element can be copied to another key element in the same crypto driver. */
    CRYPTO_11_HSM_RA_ALLOWED = 0x03, /**< key element can be read as plaintext */
    CRYPTO_11_HSM_RA_ENCRYPTED = 0x04 /**< key element can be read encrypted. E.g. SHE Ram-Key export. */
} Crypto_11_Hsm_KeyElement_ReadAccess;

/**
 */
typedef enum
{
    CRYPTO_11_HSM_WA_DENIED = 0x01, /**< key element can not be written from outside the Crypto Driver */
    CRYPTO_11_HSM_WA_INTERNAL_COPY = 0x02, /**< key element can be filled with another key element in the same crypto driver */
    CRYPTO_11_HSM_WA_ALLOWED = 0x03, /**< key element can be rewritten as plaintext */
    CRYPTO_11_HSM_WA_ENCRYPTED = 0x04 /**< key element can be written encrypted. E.g. SHE load key. */
} Crypto_11_Hsm_KeyElement_WriteAccess;

/**
 * \req [$Satisfies $SWS_Crypto 00037]
 * Key element indices imported from SWS_Csm_01022
 */
typedef enum
{
    /* MAC */
    CRYPTO_11_HSM_KE_MAC_KEY = 1,
    CRYPTO_11_HSM_KE_MAC_PROOF = 2,
    /* Signature */
    CRYPTO_11_HSM_KE_SIGNATURE_KEY = 1,
    /* Random */
    CRYPTO_11_HSM_KE_RANDOM_SEED_STATE = 3, /* Irrelevant as the seed for random number generation is always taken from TRNG in the HSM */
    CRYPTO_11_HSM_KE_RANDOM_ALGORITHM = 4, /* Irrelevant as only one key algorithm is supported by the HSM  */
    /* Cipher/AEAD */
    CRYPTO_11_HSM_KE_CIPHER_KEY = 1,
    CRYPTO_11_HSM_KE_CIPHER_IV = 5,
    CRYPTO_11_HSM_KE_CIPHER_PROOF = 6,
    CRYPTO_11_HSM_KE_CIPHER_2NDKEY = 7, /* Irrelevant as it is not supported by the HSM */
    /* Key exchange */
    CRYPTO_11_HSM_KE_KEYEXCHANGE_BASE = 8,
    CRYPTO_11_HSM_KE_KEYEXCHANGE_PRIVKEY = 9, /* Irrelevant because it is stored on the HSM when own public key is generated */
    CRYPTO_11_HSM_KE_KEYEXCHANGE_OWNPUBKEY = 10, /* This public key is generated on the HSM from its random source */
    CRYPTO_11_HSM_KE_KEYEXCHANGE_SHAREDVALUE = 1,
    CRYPTO_11_HSM_KE_KEYEXCHANGE_ALGORITHM = 12, /* Options are: Diffie-Hellman with 4 curves and Burmester-Desmedt with 3 curves. */
    /* Key derivation */
    CRYPTO_11_HSM_KE_KEYDERIVATION_PASSWORD = 1,
    CRYPTO_11_HSM_KE_KEYDERIVATION_SALT = 13,
    CRYPTO_11_HSM_KE_KEYDERIVATION_ITERATIONS = 14,
    CRYPTO_11_HSM_KE_KEYDERIVATION_ALGORITHM = 15, /* 3 different algorithms for key generation supported by the HSM */
    /* Key generate */
    CRYPTO_11_HSM_KE_KEYGENERATE_KEY = 1,
    CRYPTO_11_HSM_KE_KEYGENERATE_SEED = 16,  /* Irrelevant as the seed for key generation is always taken from TRNG in the HSM */
    CRYPTO_11_HSM_KE_KEYGENERATE_ALGORITHM = 17, /* Irrelevant as algorithm selection for key generation is not supported  */
    /* Certificate parsing */
    CRYPTO_11_HSM_KE_CERTIFICATE_DATA = 0,
    CRYPTO_11_HSM_KE_CERTIFICATE_SUBJECT_PUBLIC_KEY = 1,
    CRYPTO_11_HSM_KE_CERTIFICATE_PARSING_FORMAT = 18, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_CURRENT_TIME = 19, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_VERSION = 20, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_SERIALNUMBER = 21, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_SIGNATURE_ALGORITHM = 22, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_ISSUER = 23, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_VALIDITY_NOT_BEFORE = 24, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_VALIDITY_NOT_AFTER = 25, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_SUBJECT = 26, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_EXTENSIONS = 27, /* Irrelevant as it is not supported by the HSM */
    CRYPTO_11_HSM_KE_CERTIFICATE_SIGNATURE = 28, /* Irrelevant as it is not supported by the HSM */

    CRYPTO_11_HSM_KE_INVALID = 0xFF
} Crypto_11_Hsm_KeyElement_Id;

/**
 * Caching / Mirroring of DFLASH data to RAM
 */
typedef enum
{
  CRYPTO_11_HSM_USER_DEMAND = 0,  /**< Data will be loaded to RAM on user demand */
  CRYPTO_11_HSM_STARTUP_HSM       /**< Data will to be mirrored to RAM at HSM startup */
} Crypto_11_Hsm_MirroringT;

typedef enum
{
    KEY_STATE_IN_USE                  = 0,
    KEY_STATE_RELEASING               = 1,
    KEY_STATE_LOADING                 = 2,
    KEY_STATE_WAITING_FOR_FREE_SPACE  = 3,
    KEY_STATE_UPDATING                = 4,
    KEY_STATE_LOADED_NOT_IN_USE       = 5,
    KEY_STATE_NOT_LOADED              = 6,
    KEY_STATE_NUMBER                  = 7
} Crypto_11_Hsm_KeyState;

typedef enum
{
    KEY_ELEMENT_STATE_LOADED     = 0,
    KEY_ELEMENT_STATE_UPDATED    = 1,
    KEY_ELEMENT_STATE_NOT_LOADED = 2
} Crypto_11_Hsm_KeyElement_State;

typedef struct Crypto_11_Hsm_HsmKey Crypto_11_Hsm_HsmKey;
typedef struct Crypto_11_Hsm_Config_HsmKey Crypto_11_Hsm_Config_HsmKey;
typedef struct Crypto_11_Hsm_Config_KeyElement Crypto_11_Hsm_Config_KeyElement;

/* PRQA S 3630 1 # Struct is used internally by multiple source files */
typedef struct
{
    VAR(ecy_hsm_Csai_KeyHandleT, AUTOMATIC) keyHandle;
    VAR(Crypto_11_Hsm_KeyState, AUTOMATIC) keyState;
    /**< Stores job handle for key operations */
    VAR(ecy_hsm_Csai_JobHandleT, AUTOMATIC) hJob;
    /**< Number of sessions that are using this key to know when the key is not used and can be released. */
    VAR(uint32, AUTOMATIC) numOfSessionsUsingTheKey;
    /**< This flag is set only if a timeout occurs during key loading or releasing operation. In that case we set the state
     * to KEY_STATE_NOT_LOADED, and set this flag to ensure no keystore memory would be lost in case the key was actually
     * loaded*/
    VAR(boolean, AUTOMATIC) timeoutMaybeLoaded;
    P2CONST(Crypto_11_Hsm_HsmKey, AUTOMATIC, CRYPTO_11_HSM_CONST) pHsmKeyToRelease;
} Crypto_11_Hsm_KeyRuntimeData;

/* PRQA S 3630 1 # Struct is used internally by multiple source files */
struct Crypto_11_Hsm_Config_HsmKey
{
    /* Connects a secret key material with HSM keyId. */
    CONST(ecy_hsm_Csai_KeyIdT, AUTOMATIC) HsmKeyId;
    /* Stores the key properties which are needed for key update */
    CONST(uint32, AUTOMATIC) KeyProperties;
    /* Tells us type of the secret key material. */
    CONST(ecy_hsm_Csai_KeyTypeT, AUTOMATIC) HsmKeyType;
    /* Tells us how the secret key material should be loaded to HSM RAM. */
    CONST(Crypto_11_Hsm_MirroringT, AUTOMATIC) RamMirroring;
    /**
     * Back reference to owning key element. Gen will allow multiple key elements per HSM key, but they have to have the
     * same properties, so one pointer is sufficient.
     **/
    CONSTP2CONST(Crypto_11_Hsm_Config_KeyElement, AUTOMATIC, CRYPTO_11_HSM_CONST) pElement;
};

struct Crypto_11_Hsm_HsmKey /* PRQA S 3630 # Struct is used internally by multiple source files */
{
    CONSTP2CONST(Crypto_11_Hsm_Config_HsmKey, AUTOMATIC, CRYPTO_11_HSM_CONST) pHsmKeyConfig;
    CONSTP2VAR(Crypto_11_Hsm_KeyRuntimeData, AUTOMATIC, CRYPTO_11_HSM_VAR_NO_INIT) pHsmKeyRuntime;
};

/**
 * \brief Holds all runtime data for an element that is stored on host side.
 * \note If \ref Size is 0 no data is available (yet).
 */
typedef struct /* PRQA S 3630 # Struct is used internally by multiple source files */
{
    VAR(uint32, AUTOMATIC) Size; /**< Size of data actually written to ContentPtr */
    CONSTP2VAR(uint8, AUTOMATIC, CRYPTO_11_HSM_VAR) ContentPtr;
} Crypto_11_Hsm_KeyElement_Data;

/**
 * \brief Configuration of a CryptoKeyElement
 */
struct Crypto_11_Hsm_Config_KeyElement
{
    CONST(Crypto_11_Hsm_KeyElement_Id, AUTOMATIC) KeyElemId;
    CONST(Crypto_11_Hsm_KeyElement_Format, AUTOMATIC) Format;
    CONST(Crypto_11_Hsm_KeyElement_ReadAccess, AUTOMATIC) ReadAccess;
    CONST(Crypto_11_Hsm_KeyElement_WriteAccess, AUTOMATIC) WriteAccess;
    CONST(boolean, AUTOMATIC) AllowPartialAccess;
    CONST(boolean, AUTOMATIC) Persist;
    /* This is a pointer to data which points to an element content buffer initialized with ElementContentInitPtr. The data is allocated only if
     * (KeyElemId != 1) AND (WriteAccess == CRYPTO_11_HSM_WA_ALLOWED OR WriteAccess == CRYPTO_11_HSM_INTERNAL_COPY) */
    CONSTP2VAR(Crypto_11_Hsm_KeyElement_Data, AUTOMATIC, CRYPTO_11_HSM_VAR) ElementDataPtr;
    CONST(uint32, AUTOMATIC) Size; /**< Maximum size of a CRYPTO key element in bytes */
    CONSTP2CONST(uint8, AUTOMATIC, CRYPTO_11_HSM_CONST) ElementContentInitPtr;  /**< Value which will be used to fill the ContentPtr of ElementDataPtr during Crypto_Init() */
    /**< Refers to a key element which will contain the actual data. If the Reference is configured, the key element will be a virtual key element. */
    CONSTP2CONST(Crypto_11_Hsm_Config_KeyElement, AUTOMATIC, CRYPTO_11_HSM_CONST) VirtualTargetRef;
    CONSTP2CONST(Crypto_11_Hsm_HsmKey, AUTOMATIC, CRYPTO_11_HSM_CONST) pHsmKey;
    CONSTP2VAR(Crypto_11_Hsm_KeyElement_State, AUTOMATIC, CRYPTO_11_HSM_VAR) pKeyElementLoaded;
};

/**
 * \brief Configuration of a CryptoKeyType
 */
typedef struct
{
    CONST(uint32, AUTOMATIC) KeyElementMapIndex;
    CONST(uint32, AUTOMATIC) KeyElementsCount;
} Crypto_11_Hsm_Config_KeyType;

/**
 * \brief Configuration of a CryptoKey.
 * \note Members HsmKeyId and RamMirroring logically belong to the key element with ID 1. However since one Crypto key
 * can contain only one key element with ID 1, this member is placed here for performance increase.
 */
typedef struct
{
    CONST(uint32, AUTOMATIC) KeyTypesIndex; /* This is index for Crypto_11_Hsm_Config_KeyTypes, acting as a reference to key type */
#if (CRYPTO_11_HSM_CONFIG_ENABLE_EXTENSION == STD_ON)
    CONST(uint32, AUTOMATIC) ExtensionId; /* Extension identifier. A value of zero indicates that no extension is assigned.  */
#endif
} Crypto_11_Hsm_Config_Key;

extern CONST(Crypto_11_Hsm_Config_Primitive, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_Config_Primitives[CRYPTO_11_HSM_CONFIG_CRYPTO_PRIMITIVE_COUNT];
extern CONST(Crypto_11_Hsm_Config_DriverObject, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_Config_Objects[CRYPTO_11_HSM_CONFIG_CRYPTO_OBJECT_COUNT];
/* Each element of this array represents exactly one AUTOSAR crypto key element. This data is unchangeable during runtime. */
extern CONST(Crypto_11_Hsm_Config_KeyElement, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_Config_KeyElements[CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_ELEMENT_COUNT];
/**
 * This array implements links between key types and key elements. A key type selects a subarray of this array, whose
 * elements are indices to Crypto_11_Hsm_Config_KeyElements[] array.
 **/
extern CONST(uint32, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_KeyTypeToElementMap[CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_TYPE_ELEMENT_REFERENCES_COUNT];
/**
 * Each element of this array represents exactly one AUTOSAR crypto key type, which is a set of links toward one or
 * more key elements. This data is unchangeable during runtime.
 **/
extern CONST(Crypto_11_Hsm_Config_KeyType, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_Config_KeyTypes[CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_TYPE_COUNT];
/* Each element of this array represents exactly one AUTOSAR crypto key. This data is unchangeable during runtime */
extern CONST(Crypto_11_Hsm_Config_Key, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_Config_Keys[CRYPTO_11_HSM_CONFIG_CRYPTO_KEY_COUNT];
/* Each element of this array represents exactly one HSM key. It contains links to config and runtime data of the HSM key */
extern CONST(Crypto_11_Hsm_HsmKey, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_HsmKeys[CRYPTO_11_HSM_CONFIG_HSM_KEY_COUNT];
#if (CRYPTO_11_HSM_CONFIG_HAS_SHE_SERVICES == STD_ON)
/**
 * Two dimensional array containing SHE timeouts. First index is service of a job, second index is determined by the
 * processing mode of the job (SYNC or ASYNC).
**/
extern CONST(uint32, CRYPTO_11_HSM_CONST) Crypto_11_Hsm_SheTimeouts[CRYPTO_11_HSM_SHE_SUPPORTED_SERVICE_TIMEOUT_CNT]
                                                                   [CRYPTO_11_HSM_SHE_TIMEOUT_SUBINDICES];
#endif

#endif
